@@ -11,12 +11,12 @@ use std::marker::PhantomData;
 
 use nalgebra::{
     allocator::Allocator, convert, storage::StorageMut, ComplexField, DefaultAllocator, DimMin,
-    DimName, OVector, Vector, U1,
+    DimName, IsContiguous, OVector, Vector, U1,
 };
 use thiserror::Error;
 
 use crate::{
-    core::{Domain, Error, Problem, System},
+    core::{Domain, Problem, ProblemError, System},
     derivatives::{Jacobian, JacobianError, EPSILON_SQRT},
 };
 
@@ -25,7 +25,7 @@ use crate::{
 pub enum InitialGuessAnalysisError {
     /// Error that occurred when evaluating the system.
     #[error("{0}")]
-    System(#[from] Error),
+    System(#[from] ProblemError),
     /// Error that occurred when computing the Jacobian matrix.
     #[error("{0}")]
     Jacobian(#[from] JacobianError),
@@ -52,7 +52,7 @@ where
         fx: &mut Vector<F::Scalar, F::Dim, Sfx>,
     ) -> Result<Self, InitialGuessAnalysisError>
     where
-        Sx: StorageMut<F::Scalar, F::Dim>,
+        Sx: StorageMut<F::Scalar, F::Dim> + IsContiguous,
         Sfx: StorageMut<F::Scalar, F::Dim>,
     {
         let scale_iter = dom.vars().iter().map(|var| var.scale());
