@@ -6,12 +6,12 @@ use nalgebra::{
     allocator::Allocator,
     convert,
     storage::{Storage, StorageMut},
-    ComplexField, DefaultAllocator, OMatrix, RealField, Vector,
+    ComplexField, DefaultAllocator, IsContiguous, OMatrix, RealField, Vector,
 };
 use num_traits::{One, Zero};
 use thiserror::Error;
 
-use crate::core::{Error, Problem, System};
+use crate::core::{Problem, ProblemError, System};
 
 /// Square root of double precision machine epsilon. This value is a standard
 /// constant for epsilons in approximating derivate-based concepts.
@@ -22,7 +22,7 @@ pub const EPSILON_SQRT: f64 = 0.000000014901161193847656;
 pub enum JacobianError {
     /// Error that occurred when evaluating the system.
     #[error("{0}")]
-    Problem(#[from] Error),
+    Problem(#[from] ProblemError),
 }
 
 /// Jacobian matrix of a system.
@@ -60,7 +60,7 @@ where
         fx: &Vector<F::Scalar, F::Dim, Sfx>,
     ) -> Result<Self, JacobianError>
     where
-        Sx: StorageMut<F::Scalar, F::Dim>,
+        Sx: StorageMut<F::Scalar, F::Dim> + IsContiguous,
         Sscale: Storage<F::Scalar, F::Dim>,
         Sfx: Storage<F::Scalar, F::Dim>,
     {
@@ -86,7 +86,7 @@ where
         fx: &Vector<F::Scalar, F::Dim, Sfx>,
     ) -> Result<&mut Self, JacobianError>
     where
-        Sx: StorageMut<F::Scalar, F::Dim>,
+        Sx: StorageMut<F::Scalar, F::Dim> + IsContiguous,
         Sscale: Storage<F::Scalar, F::Dim>,
         Sfx: Storage<F::Scalar, F::Dim>,
     {
