@@ -23,14 +23,14 @@ use nalgebra::{
     allocator::Allocator,
     convert,
     storage::{Storage, StorageMut},
-    DefaultAllocator, Dim, DimName, OVector, RealField, Vector, U1,
+    DefaultAllocator, Dim, DimName, IsContiguous, OVector, RealField, Vector, U1,
 };
 use num_traits::{One, Zero};
 use thiserror::Error;
 
 use crate::{
     core::{
-        Domain, Error, Function, FunctionResultExt, Optimizer, Problem, Solver, System,
+        Domain, Function, FunctionResultExt, Optimizer, Problem, ProblemError, Solver, System,
         VectorDomainExt,
     },
     derivatives::EPSILON_SQRT,
@@ -182,7 +182,7 @@ where
 pub enum NelderMeadError {
     /// Error that occurred when evaluating the system.
     #[error("{0}")]
-    Problem(#[from] Error),
+    Problem(#[from] ProblemError),
     /// Simplex collapsed so it is impossible to make any progress.
     #[error("simplex collapsed")]
     SimplexCollapsed,
@@ -200,7 +200,7 @@ where
         x: &mut Vector<<F>::Scalar, <F>::Dim, Sx>,
     ) -> Result<F::Scalar, NelderMeadError>
     where
-        Sx: StorageMut<<F>::Scalar, <F>::Dim>,
+        Sx: StorageMut<<F>::Scalar, <F>::Dim> + IsContiguous,
     {
         let NelderMeadOptions {
             reflection_coeff,
@@ -249,7 +249,7 @@ where
                     // hope that it gets replaced. The exception is the very
                     // point provided by the caller as it is expected to be
                     // valid and it is erroneous situation if it is not.
-                    Err(Error::InvalidValue) => inf,
+                    Err(ProblemError::InvalidValue) => inf,
                     Err(error) => {
                         // Clear the simplex so the solver is not in invalid
                         // state.
@@ -274,7 +274,7 @@ where
                 // The simplex is too degenerate.
                 simplex.clear();
                 errors.clear();
-                return Err(NelderMeadError::Problem(Error::InvalidValue));
+                return Err(NelderMeadError::Problem(ProblemError::InvalidValue));
             }
 
             sort_perm.extend(0..=n);
@@ -488,7 +488,7 @@ where
         x: &mut Vector<F::Scalar, F::Dim, Sx>,
     ) -> Result<F::Scalar, Self::Error>
     where
-        Sx: StorageMut<F::Scalar, F::Dim>,
+        Sx: StorageMut<F::Scalar, F::Dim> + IsContiguous,
     {
         self.next_inner(f, dom, x)
     }
@@ -511,7 +511,7 @@ where
         fx: &mut Vector<<F>::Scalar, <F>::Dim, Sfx>,
     ) -> Result<(), Self::Error>
     where
-        Sx: StorageMut<<F>::Scalar, <F>::Dim>,
+        Sx: StorageMut<<F>::Scalar, <F>::Dim> + IsContiguous,
         Sfx: StorageMut<<F>::Scalar, <F>::Dim>,
     {
         self.next_inner(f, dom, x).map(|_| {
