@@ -23,13 +23,14 @@ use std::error::Error as StdError;
 use nalgebra::{
     allocator::Allocator,
     storage::{Storage, StorageMut},
-    vector, DVector, DefaultAllocator, Dim, DimName, Dynamic, OVector, Vector, U1, U2,
+    vector, DVector, DefaultAllocator, Dim, DimName, Dynamic, IsContiguous, OVector, Vector, U1,
+    U2,
 };
 use num_traits::Signed;
 use thiserror::Error;
 
 use crate::{
-    core::{Domain, Error, Problem, Solver, System},
+    core::{Domain, Problem, ProblemError, Solver, System},
     var,
 };
 
@@ -55,7 +56,7 @@ where
     /// Test if given point is a root of the system, given the tolerance `eps`.
     fn is_root<Sx>(&self, x: &Vector<Self::Scalar, Self::Dim, Sx>, eps: Self::Scalar) -> bool
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
     {
         let mut fx = x.clone_owned();
         if self.eval(x, &mut fx).is_ok() {
@@ -139,9 +140,9 @@ impl System for ExtendedRosenbrock {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         for i in 0..(self.n / 2) {
@@ -234,9 +235,9 @@ impl System for ExtendedPowell {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         for i in 0..(self.n / 4) {
@@ -319,9 +320,9 @@ impl System for BullardBiegler {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         fx[0] = 1e4 * x[0] * x[1] - 1.0;
@@ -387,9 +388,9 @@ impl System for Sphere {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         for i in 0..self.n {
@@ -458,9 +459,9 @@ impl System for Brown {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         fx[0] = x.iter().product::<f64>() - 1.0;
@@ -523,9 +524,9 @@ impl System for Exponential {
         &self,
         x: &Vector<Self::Scalar, Self::Dim, Sx>,
         fx: &mut Vector<Self::Scalar, Self::Dim, Sfx>,
-    ) -> Result<(), Error>
+    ) -> Result<(), ProblemError>
     where
-        Sx: Storage<Self::Scalar, Self::Dim>,
+        Sx: Storage<Self::Scalar, Self::Dim> + IsContiguous,
         Sfx: StorageMut<Self::Scalar, Self::Dim>,
     {
         for i in 0..self.n {
